@@ -40,7 +40,7 @@ import (
 	logf "sigs.k8s.io/controller-runtime/pkg/log"
 	"sigs.k8s.io/controller-runtime/pkg/reconcile"
 
-	cdiv1 "kubevirt.io/containerized-data-importer/pkg/apis/core/v1beta1"
+	cdiv1 "kubevirt.io/containerized-data-importer-api/pkg/apis/core/v1beta1"
 	"kubevirt.io/containerized-data-importer/pkg/common"
 	"kubevirt.io/containerized-data-importer/pkg/token"
 	"kubevirt.io/containerized-data-importer/pkg/util/cert/fetcher"
@@ -73,6 +73,14 @@ type FakeValidator struct {
 	Params    map[string]string
 }
 
+type FakeGenerator struct {
+	token string
+}
+
+func (g *FakeGenerator) Generate(*token.Payload) (string, error) {
+	return g.token, nil
+}
+
 var _ = Describe("Clone controller reconcile loop", func() {
 	var (
 		reconciler *CloneReconciler
@@ -129,11 +137,11 @@ var _ = Describe("Clone controller reconcile loop", func() {
 			AnnUploadClientName: "uploadclient"}, nil)
 		reconciler = createCloneReconciler(testPvc, createPvc("source", "default", map[string]string{}, nil))
 		By("Setting up the match token")
-		reconciler.tokenValidator.(*FakeValidator).match = "foobaz"
-		reconciler.tokenValidator.(*FakeValidator).Name = "source"
-		reconciler.tokenValidator.(*FakeValidator).Namespace = "default"
-		reconciler.tokenValidator.(*FakeValidator).Params["targetNamespace"] = "default"
-		reconciler.tokenValidator.(*FakeValidator).Params["targetName"] = "testPvc1"
+		reconciler.shortTokenValidator.(*FakeValidator).match = "foobaz"
+		reconciler.shortTokenValidator.(*FakeValidator).Name = "source"
+		reconciler.shortTokenValidator.(*FakeValidator).Namespace = "default"
+		reconciler.shortTokenValidator.(*FakeValidator).Params["targetNamespace"] = "default"
+		reconciler.shortTokenValidator.(*FakeValidator).Params["targetName"] = "testPvc1"
 		By("Verifying no source pod exists")
 		sourcePod, err := reconciler.findCloneSourcePod(testPvc)
 		Expect(sourcePod).To(BeNil())
@@ -159,17 +167,17 @@ var _ = Describe("Clone controller reconcile loop", func() {
 		sourcePvc := createPvc("source", "default", map[string]string{}, nil)
 		reconciler = createCloneReconciler(testPvc, sourcePvc, podFunc(sourcePvc))
 		By("Setting up the match token")
-		reconciler.tokenValidator.(*FakeValidator).match = "foobaz"
-		reconciler.tokenValidator.(*FakeValidator).Name = "source"
-		reconciler.tokenValidator.(*FakeValidator).Namespace = "default"
-		reconciler.tokenValidator.(*FakeValidator).Params["targetNamespace"] = "default"
-		reconciler.tokenValidator.(*FakeValidator).Params["targetName"] = "testPvc1"
+		reconciler.shortTokenValidator.(*FakeValidator).match = "foobaz"
+		reconciler.shortTokenValidator.(*FakeValidator).Name = "source"
+		reconciler.shortTokenValidator.(*FakeValidator).Namespace = "default"
+		reconciler.shortTokenValidator.(*FakeValidator).Params["targetNamespace"] = "default"
+		reconciler.shortTokenValidator.(*FakeValidator).Params["targetName"] = "testPvc1"
 		By("Verifying no source pod exists")
 		sourcePod, err := reconciler.findCloneSourcePod(testPvc)
 		Expect(sourcePod).To(BeNil())
 		result, err := reconciler.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
 		Expect(err).ToNot(HaveOccurred())
-		Expect(result.Requeue).To(BeTrue())
+		Expect(result.RequeueAfter).ToNot(BeZero())
 		By("Verifying source pod does not exist")
 		sourcePod, err = reconciler.findCloneSourcePod(testPvc)
 		Expect(err).ToNot(HaveOccurred())
@@ -206,11 +214,11 @@ var _ = Describe("Clone controller reconcile loop", func() {
 		}
 		reconciler = createCloneReconciler(objs...)
 		By("Setting up the match token")
-		reconciler.tokenValidator.(*FakeValidator).match = "foobaz"
-		reconciler.tokenValidator.(*FakeValidator).Name = "source"
-		reconciler.tokenValidator.(*FakeValidator).Namespace = "default"
-		reconciler.tokenValidator.(*FakeValidator).Params["targetNamespace"] = "default"
-		reconciler.tokenValidator.(*FakeValidator).Params["targetName"] = "testPvc1"
+		reconciler.shortTokenValidator.(*FakeValidator).match = "foobaz"
+		reconciler.shortTokenValidator.(*FakeValidator).Name = "source"
+		reconciler.shortTokenValidator.(*FakeValidator).Namespace = "default"
+		reconciler.shortTokenValidator.(*FakeValidator).Params["targetNamespace"] = "default"
+		reconciler.shortTokenValidator.(*FakeValidator).Params["targetName"] = "testPvc1"
 		By("Verifying no source pod exists")
 		sourcePod, err := reconciler.findCloneSourcePod(testPvc)
 		Expect(sourcePod).To(BeNil())
@@ -221,6 +229,7 @@ var _ = Describe("Clone controller reconcile loop", func() {
 		Expect(err).ToNot(HaveOccurred())
 		Expect(sourcePod).ToNot(BeNil())
 		Expect(sourcePod.GetLabels()[CloneUniqueID]).To(Equal("default-testPvc1-source-pod"))
+		Expect(sourcePod.GetLabels()[common.AppKubernetesPartOfLabel]).To(Equal("testing"))
 		By("Verifying source pod annotations passed from pvc")
 		Expect(sourcePod.GetAnnotations()[AnnPodNetwork]).To(Equal("net1"))
 		Expect(sourcePod.GetAnnotations()[AnnPodSidecarInjection]).To(Equal(AnnPodSidecarInjectionDefault))
@@ -263,31 +272,49 @@ var _ = Describe("Clone controller reconcile loop", func() {
 	It("Should error with missing upload client name annotation if none provided", func() {
 		testPvc := createPvc("testPvc1", "default", map[string]string{
 			AnnCloneRequest: "default/source", AnnPodReady: "true", AnnCloneToken: "foobaz", AnnCloneSourcePod: "default-testPvc1-source-pod"}, nil)
-		reconciler = createCloneReconciler(testPvc, createPvc("source", "default", map[string]string{}, nil))
+		sourcePod := createSourcePod(testPvc, string(testPvc.GetUID()))
+		sourcePod.Namespace = "default"
+		reconciler = createCloneReconciler(testPvc, createPvc("source", "default", map[string]string{}, nil), sourcePod)
 		By("Setting up the match token")
-		reconciler.tokenValidator.(*FakeValidator).match = "foobaz"
-		reconciler.tokenValidator.(*FakeValidator).Name = "source"
-		reconciler.tokenValidator.(*FakeValidator).Namespace = "default"
-		reconciler.tokenValidator.(*FakeValidator).Params["targetNamespace"] = "default"
-		reconciler.tokenValidator.(*FakeValidator).Params["targetName"] = "testPvc1"
-		By("Verifying no source pod exists")
-		sourcePod, err := reconciler.findCloneSourcePod(testPvc)
-		Expect(sourcePod).To(BeNil())
-		_, err = reconciler.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
+		reconciler.shortTokenValidator.(*FakeValidator).match = "foobaz"
+		reconciler.shortTokenValidator.(*FakeValidator).Name = "source"
+		reconciler.shortTokenValidator.(*FakeValidator).Namespace = "default"
+		reconciler.shortTokenValidator.(*FakeValidator).Params["targetNamespace"] = "default"
+		reconciler.shortTokenValidator.(*FakeValidator).Params["targetName"] = "testPvc1"
+		_, err := reconciler.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
 		Expect(err).To(HaveOccurred())
 		Expect(err.Error()).To(ContainSubstring("missing required " + AnnUploadClientName + " annotation"))
 	})
 
+	It("Should create cert secret", func() {
+		testPvc := createPvc("testPvc1", "default", map[string]string{
+			AnnCloneRequest: "default/source", AnnPodReady: "true", AnnCloneToken: "foobaz", AnnCloneSourcePod: "default-testPvc1-source-pod", AnnUploadClientName: "uploadclient"}, nil)
+		sourcePod := createSourcePod(testPvc, string(testPvc.GetUID()))
+		sourcePod.Namespace = "default"
+		reconciler = createCloneReconciler(testPvc, createPvc("source", "default", map[string]string{}, nil), sourcePod)
+		By("Setting up the match token")
+		reconciler.shortTokenValidator.(*FakeValidator).match = "foobaz"
+		reconciler.shortTokenValidator.(*FakeValidator).Name = "source"
+		reconciler.shortTokenValidator.(*FakeValidator).Namespace = "default"
+		reconciler.shortTokenValidator.(*FakeValidator).Params["targetNamespace"] = "default"
+		reconciler.shortTokenValidator.(*FakeValidator).Params["targetName"] = "testPvc1"
+		_, err := reconciler.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: "testPvc1", Namespace: "default"}})
+		Expect(err).ToNot(HaveOccurred())
+		secret := &corev1.Secret{}
+		reconciler.client.Get(context.TODO(), types.NamespacedName{Namespace: sourcePod.Namespace, Name: sourcePod.Name}, secret)
+		Expect(err).ToNot(HaveOccurred())
+	})
+
 	It("Should update the PVC from the pod status", func() {
 		testPvc := createPvc("testPvc1", "default", map[string]string{
 			AnnCloneRequest: "default/source", AnnPodReady: "true", AnnCloneToken: "foobaz", AnnUploadClientName: "uploadclient", AnnCloneSourcePod: "default-testPvc1-source-pod"}, nil)
 		reconciler = createCloneReconciler(testPvc, createPvc("source", "default", map[string]string{}, nil))
 		By("Setting up the match token")
-		reconciler.tokenValidator.(*FakeValidator).match = "foobaz"
-		reconciler.tokenValidator.(*FakeValidator).Name = "source"
-		reconciler.tokenValidator.(*FakeValidator).Namespace = "default"
-		reconciler.tokenValidator.(*FakeValidator).Params["targetNamespace"] = "default"
-		reconciler.tokenValidator.(*FakeValidator).Params["targetName"] = "testPvc1"
+		reconciler.shortTokenValidator.(*FakeValidator).match = "foobaz"
+		reconciler.shortTokenValidator.(*FakeValidator).Name = "source"
+		reconciler.shortTokenValidator.(*FakeValidator).Namespace = "default"
+		reconciler.shortTokenValidator.(*FakeValidator).Params["targetNamespace"] = "default"
+		reconciler.shortTokenValidator.(*FakeValidator).Params["targetName"] = "testPvc1"
 		By("Verifying no source pod exists")
 		sourcePod, err := reconciler.findCloneSourcePod(testPvc)
 		Expect(sourcePod).To(BeNil())
@@ -303,11 +330,11 @@ var _ = Describe("Clone controller reconcile loop", func() {
 		testPvc := createTargetPvcFunc()
 		reconciler = createCloneReconciler(testPvc, createSourcePvcFunc())
 		By("Setting up the match token")
-		reconciler.tokenValidator.(*FakeValidator).match = "foobaz"
-		reconciler.tokenValidator.(*FakeValidator).Name = "source"
-		reconciler.tokenValidator.(*FakeValidator).Namespace = "default"
-		reconciler.tokenValidator.(*FakeValidator).Params["targetNamespace"] = "default"
-		reconciler.tokenValidator.(*FakeValidator).Params["targetName"] = "testPvc1"
+		reconciler.shortTokenValidator.(*FakeValidator).match = "foobaz"
+		reconciler.shortTokenValidator.(*FakeValidator).Name = "source"
+		reconciler.shortTokenValidator.(*FakeValidator).Namespace = "default"
+		reconciler.shortTokenValidator.(*FakeValidator).Params["targetNamespace"] = "default"
+		reconciler.shortTokenValidator.(*FakeValidator).Params["targetName"] = "testPvc1"
 		By("Verifying no source pod exists")
 		sourcePod, err := reconciler.findCloneSourcePod(testPvc)
 		Expect(sourcePod).To(BeNil())
@@ -404,11 +431,11 @@ var _ = Describe("Clone controller reconcile loop", func() {
 		testPvc := createTargetPvcFunc()
 		reconciler = createCloneReconciler(testPvc, createSourcePvcFunc())
 		By("Setting up the match token")
-		reconciler.tokenValidator.(*FakeValidator).match = "foobaz"
-		reconciler.tokenValidator.(*FakeValidator).Name = "source"
-		reconciler.tokenValidator.(*FakeValidator).Namespace = "default"
-		reconciler.tokenValidator.(*FakeValidator).Params["targetNamespace"] = "default"
-		reconciler.tokenValidator.(*FakeValidator).Params["targetName"] = "testPvc1"
+		reconciler.shortTokenValidator.(*FakeValidator).match = "foobaz"
+		reconciler.shortTokenValidator.(*FakeValidator).Name = "source"
+		reconciler.shortTokenValidator.(*FakeValidator).Namespace = "default"
+		reconciler.shortTokenValidator.(*FakeValidator).Params["targetNamespace"] = "default"
+		reconciler.shortTokenValidator.(*FakeValidator).Params["targetName"] = "testPvc1"
 		By("Verifying no source pod exists")
 		sourcePod, err := reconciler.findCloneSourcePod(testPvc)
 		Expect(sourcePod).To(BeNil())
@@ -586,7 +613,7 @@ var _ = Describe("Update PVC", func() {
 
 var _ = Describe("TokenValidation", func() {
 	g := token.NewGenerator(common.CloneTokenIssuer, getAPIServerKey(), 5*time.Minute)
-	v := newCloneTokenValidator(&getAPIServerKey().PublicKey)
+	v := newCloneTokenValidator(common.CloneTokenIssuer, &getAPIServerKey().PublicKey)
 
 	goodTokenData := func() *token.Payload {
 		return &token.Payload{
@@ -646,7 +673,7 @@ var _ = Describe("TokenValidation", func() {
 				},
 			},
 		}
-		err = validateCloneTokenPVC(v, source, target)
+		err = validateCloneTokenPVC(tokenString, v, source, target)
 		if expectedSuccess {
 			Expect(err).ToNot(HaveOccurred())
 			Expect(reflect.DeepEqual(p, goodTokenData())).To(BeTrue())
@@ -672,7 +699,7 @@ func createCloneReconciler(objects ...runtime.Object) *CloneReconciler {
 	objs = append(objs, MakeEmptyCDICR())
 	cdiConfig := MakeEmptyCDIConfigSpec(common.ConfigName)
 	cdiConfig.Status = cdiv1.CDIConfigStatus{
-		DefaultPodResourceRequirements: createDefaultPodResourceRequirements(int64(0), int64(0), int64(0), int64(0)),
+		DefaultPodResourceRequirements: createDefaultPodResourceRequirements("", "", "", ""),
 	}
 	objs = append(objs, cdiConfig)
 
@@ -689,12 +716,16 @@ func createCloneReconciler(objects ...runtime.Object) *CloneReconciler {
 		scheme:   s,
 		log:      cloneLog,
 		recorder: rec,
-		tokenValidator: &FakeValidator{
+		shortTokenValidator: &FakeValidator{
 			Params: make(map[string]string, 0),
 		},
 		image:               testImage,
 		clientCertGenerator: &fakeCertGenerator{},
 		serverCAFetcher:     &fetcher.MemCertBundleFetcher{Bundle: []byte("baz")},
+		installerLabels: map[string]string{
+			common.AppKubernetesPartOfLabel:  "testing",
+			common.AppKubernetesVersionLabel: "v0.0.0-tests",
+		},
 	}
 }
 
@@ -791,7 +822,7 @@ func createSourcePod(pvc *corev1.PersistentVolumeClaim, pvcUID string) *corev1.P
 	podName := fmt.Sprintf("%s-%s-", common.ClonerSourcePodName, sourcePvcName)
 	pod := &corev1.Pod{
 		ObjectMeta: metav1.ObjectMeta{
-			GenerateName: podName,
+			Name: podName,
 			Annotations: map[string]string{
 				AnnCreatedBy: "yes",
 				AnnOwnerRef:  fmt.Sprintf("%s/%s", pvc.Namespace, pvc.Name),
@@ -800,8 +831,8 @@ func createSourcePod(pvc *corev1.PersistentVolumeClaim, pvcUID string) *corev1.P
 				common.CDILabelKey:       common.CDILabelValue, //filtered by the podInformer
 				common.CDIComponentLabel: common.ClonerSourcePodName,
 				// this label is used when searching for a pvc's cloner source pod.
-				CloneUniqueID:          pvcUID + "-source-pod",
-				common.PrometheusLabel: "",
+				CloneUniqueID:             pvcUID + "-source-pod",
+				common.PrometheusLabelKey: common.PrometheusLabelValue,
 			},
 		},
 		Spec: corev1.PodSpec{
@@ -815,12 +846,26 @@ func createSourcePod(pvc *corev1.PersistentVolumeClaim, pvcUID string) *corev1.P
 					ImagePullPolicy: corev1.PullAlways,
 					Env: []corev1.EnvVar{
 						{
-							Name:  "CLIENT_KEY",
-							Value: "bar",
+							Name: "CLIENT_KEY",
+							ValueFrom: &corev1.EnvVarSource{
+								SecretKeyRef: &corev1.SecretKeySelector{
+									LocalObjectReference: corev1.LocalObjectReference{
+										Name: podName,
+									},
+									Key: "tls.key",
+								},
+							},
 						},
 						{
-							Name:  "CLIENT_CERT",
-							Value: "foo",
+							Name: "CLIENT_CERT",
+							ValueFrom: &corev1.EnvVarSource{
+								SecretKeyRef: &corev1.SecretKeySelector{
+									LocalObjectReference: corev1.LocalObjectReference{
+										Name: podName,
+									},
+									Key: "tls.crt",
+								},
+							},
 						},
 						{
 							Name:  "SERVER_CA_CERT",
